==> ktorrent-5.0.tar.xz: ktorrent-5.0/ktorrent/pref/btpref.cpp <==
/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#include <kdeversion.h>
#include <klocalizedstring.h>
#include "btpref.h"
#include "settings.h"

namespace kt
{
    BTPref::BTPref(QWidget* parent): PrefPageInterface(Settings::self(), i18n("BitTorrent"), "application-x-bittorrent", parent)
    {
        setupUi(this);
    }

    BTPref::~BTPref()
    {
    }

    void BTPref::loadSettings()
    {
        kcfg_allowUnencryptedConnections->setEnabled(Settings::useEncryption());
        kcfg_dhtPort->setEnabled(Settings::dhtSupport());
        kcfg_customIP->setEnabled(Settings::useCustomIP());
    }

}

==> ktorrent_5.1.2.orig.tar.xz: ktorrent-5.1.2/ktorrent/pref/btpref.cpp <==
/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#include <KLocalizedString>

#include "btpref.h"
#include "settings.h"

namespace kt
{
    BTPref::BTPref(QWidget* parent): PrefPageInterface(Settings::self(), i18n("BitTorrent"), QStringLiteral("application-x-bittorrent"), parent)
    {
        setupUi(this);
    }

    BTPref::~BTPref()
    {
    }

    void BTPref::loadSettings()
    {
        kcfg_allowUnencryptedConnections->setEnabled(Settings::useEncryption());
        kcfg_dhtPort->setEnabled(Settings::dhtSupport());
        kcfg_customIP->setEnabled(Settings::useCustomIP());
    }

}
